@@ -1,8 +1,16 @@
+/* 1.0/Util.java:
+ *
+ * Copyright (C) 1997, 1998, Kenneth Albanowski
+ *
+ * This is free software, licensed under the GNU Library Public License V2.
+ * See the file COPYING.LIB for details.
+ */
+
 package Pdapilot;
 
 public class Util {
 	static public String prettyPrint(byte[] b)
-		{ return prettyPrint(new String(b,0,b.length)); }
+		{ return prettyPrint(new String(b,0)); }
 	static public String prettyPrint(Object o) {
 		if (o == null) {
 			return "null";
@@ -30,8 +38,8 @@ public class Util {
 		}
 		return out.toString();
 	}
-    static public String readLine() throws java.io.IOException {
-        java.io.BufferedReader dis = new java.io.BufferedReader(new java.io.InputStreamReader(System.in));
-        return dis.readLine();
-    }
+	static public String readLine() throws java.io.IOException {
+		java.io.DataInputStream dis = new java.io.DataInputStream(System.in);
+		return dis.readLine();
+	}
 }
\ No newline at end of file
