@@ -1,3 +1,10 @@
+/* 1.1/Char4.java:
+ *
+ * Copyright (C) 1997, 1998, Kenneth Albanowski
+ *
+ * This is free software, licensed under the GNU Library Public License V2.
+ * See the file COPYING.LIB for details.
+ */
 
 package Pdapilot;
 
@@ -31,8 +38,7 @@ public class Char4 {
 	}
 
 	public void set(String id) {
-		byte[] by = new byte[4];
-		id.getBytes(0, 4, by, 0);
+		byte[] by = id.getBytes();
 		try {
 			this.set(by);
 		} catch(java.lang.CloneNotSupportedException e) {
@@ -54,7 +60,7 @@ public class Char4 {
 	}
 
 	public String getString() {
-		return new String(b, 0);
+		return new String(b, 0, b.length);
 	}
 	
 	public boolean equals(Char4 other) {
