@@ -11,6 +11,7 @@ extern "C" {
 
 extern double get_float PI_ARGS((void *));
 extern void set_float PI_ARGS((void *, double));
+extern int compareTm PI_ARGS((struct tm *a, struct tm *b));
 
 #ifdef __cplusplus
 }
@@ -59,7 +60,7 @@ extern void set_float PI_ARGS((void *, double));
                                 ((signed char)(get_byte((ptr))))\
                                 )
 
-#define set_long(ptr,val) ((((unsigned char*)(ptr))[0] = (((unsigned long)(val)) >> 24) & 0xff), \
+#define set_long(ptr,val) ((((unsigned char*)(ptr))[0] = (unsigned char)(((unsigned long)(val)) >> 24) & 0xff), \
 		          (((unsigned char*)(ptr))[1] = (((unsigned long)(val)) >> 16) & 0xff), \
 		          (((unsigned char*)(ptr))[2] = (((unsigned long)(val)) >> 8) & 0xff), \
 		          (((unsigned char*)(ptr))[3] = (((unsigned long)(val)) >> 0) & 0xff))
@@ -70,7 +71,7 @@ extern void set_float PI_ARGS((void *, double));
                             (val)\
                            )))
 
-#define set_treble(ptr,val) ((((unsigned char*)(ptr))[0] = (((unsigned long)(val)) >> 16) & 0xff), \
+#define set_treble(ptr,val) ((((unsigned char*)(ptr))[0] = (unsigned char)(((unsigned long)(val)) >> 16) & 0xff), \
 		             (((unsigned char*)(ptr))[1] = (((unsigned long)(val)) >> 8) & 0xff), \
 		             (((unsigned char*)(ptr))[2] = (((unsigned long)(val)) >> 0) & 0xff))
 
@@ -167,10 +168,10 @@ inline void set_long(void *buf, const unsigned long val)
 {
      unsigned char *ptr = (unsigned char *) buf;
 
-     *ptr = (val >> 24) & 0xff;
-     *(++ptr) = (val >> 16) & 0xff;
-     *(++ptr) = (val >> 8) & 0xff;
-     *(++ptr) = val & 0xff;
+     *ptr = (unsigned char)((val >> 24) & 0xff);
+     *(++ptr) = (unsigned char)((val >> 16) & 0xff);
+     *(++ptr) = (unsigned char)((val >> 8) & 0xff);
+     *(++ptr) = (unsigned char)(val & 0xff);
 }
 
 inline void set_slong(void *buf, const signed long val) 
@@ -189,9 +190,9 @@ inline void set_treble(void *buf, const unsigned long val)
 {
      unsigned char *ptr = (unsigned char *) buf;
      
-     *ptr = (val >> 16) & 0xff;
-     *(++ptr) = (val >> 8) & 0xff;
-     *(++ptr) = val & 0xff;
+     *ptr = (unsigned char)((val >> 16) & 0xff);
+     *(++ptr) = (unsigned char)((val >> 8) & 0xff);
+     *(++ptr) = (unsigned char)(val & 0xff);
 }
 
 inline void set_streble(void *buf, const signed long val) 
