@@ -21,12 +21,18 @@ extern "C" {
 #define PI_SOCK_RAW       0x0030
 #define PI_SOCK_SEQPACKET 0x0040
 
+#define PI_SLP_SPEED	0x0001
+
 #define PI_PilotSocketDLP       3
 #define PI_PilotSocketConsole   1
 #define PI_PilotSocketDebugger  0
 #define PI_PilotSocketRemoteUI  2
 
+#ifdef WIN32
+#include "pi-sockaddr-win32.h"
+#else
 #include "pi-sockaddr.h"
+#endif
 
 struct pi_skb;
 
@@ -42,6 +48,8 @@ extern int pi_bind PI_ARGS((int pi_sd, struct sockaddr *my_addr, int addrlen));
 extern int pi_listen PI_ARGS((int pi_sd, int backlog));
 extern int pi_accept PI_ARGS((int pi_sd, struct sockaddr *remote_addr, int *addrlen));
 
+extern int pi_accept_to PI_ARGS((int pi_sd, struct sockaddr *addr, int *addrlen, int timeout));
+
 extern int pi_send PI_ARGS((int pi_sd, void *msg, int len, unsigned int flags));
 extern int pi_recv PI_ARGS((int pi_sd, void *msg, int len, unsigned int flags));
 
@@ -51,6 +59,9 @@ extern int pi_write PI_ARGS((int pi_sd, void *msg, int len));
 extern int pi_getsockname PI_ARGS((int pi_sd, struct sockaddr * addr, int * namelen));
 extern int pi_getsockpeer PI_ARGS((int pi_sd, struct sockaddr * addr, int * namelen));
 
+extern int pi_setmaxspeed PI_ARGS((int pi_sd, int speed, int overclock));
+extern int pi_getsockopt PI_ARGS((int pi_sd, int level, int option_name, void * option_value, int * option_len));
+
 extern int pi_version PI_ARGS((int pi_sd));
 
 extern int pi_tickle PI_ARGS((int pi_sd));
@@ -58,6 +69,7 @@ extern int pi_watchdog PI_ARGS((int pi_sd, int interval));
 
 extern int pi_close PI_ARGS((int pi_sd));
 
+
 #ifdef __cplusplus
 }
 #endif
